summaryrefslogtreecommitdiff
path: root/sysdeps/common
diff options
context:
space:
mode:
authorRobert Roth <robert.roth.off@gmail.com>2017-05-12 05:08:41 +0300
committerRobert Roth <robert.roth.off@gmail.com>2017-05-12 05:08:41 +0300
commit1bf16bfffd28e6724c35589e49db10a10cae594d (patch)
tree1fc0bac8c4b8b3d60aa9374fb7893fefc1368ca8 /sysdeps/common
parentc29d7de9a087ff781be5463f4d9efc9a8f6abbe4 (diff)
downloadlibgtop-1bf16bfffd28e6724c35589e49db10a10cae594d.tar.gz
Renamed procdiskio to procio
Diffstat (limited to 'sysdeps/common')
-rw-r--r--sysdeps/common/default.c6
-rw-r--r--sysdeps/common/sysdeps_suid.c4
2 files changed, 5 insertions, 5 deletions
diff --git a/sysdeps/common/sysdeps_suid.c b/sysdeps/common/sysdeps_suid.c
index 70dd2256..24953176 100644
--- a/sysdeps/common/sysdeps_suid.c
+++ b/sysdeps/common/sysdeps_suid.c
@@ -90,8 +90,8 @@ const _glibtop_init_func_t _glibtop_init_hook_p [] = {
#if GLIBTOP_SUID_PPP
_glibtop_init_ppp_p,
#endif
-#if GLIBTOP_SUID_PROC_DISKIO
- _glibtop_init_proc_diskio_p,
+#if GLIBTOP_SUID_PROC_IO
+ _glibtop_init_proc_io_p,
#endif
NULL
};
diff --git a/sysdeps/common/default.c b/sysdeps/common/default.c
index 6987fb20..e3b096f2 100644
--- a/sysdeps/common/default.c
+++ b/sysdeps/common/default.c
@@ -433,7 +433,7 @@ glibtop_get_proc_affinity(glibtop_proc_affinity *buf, pid_t pid)
}
/**
* glibtop_get_proc_diskio: Get the disk io stats for the given pid
* @buf: Buffer where the result will be given
* @pid: Process id to get the io stats for
*
@@ -442,7 +442,7 @@ glibtop_get_proc_affinity(glibtop_proc_affinity *buf, pid_t pid)
* Returns: A list of processor ID of 'buf.number' elements.
*/
void
-glibtop_get_proc_diskio(glibtop_proc_diskio *buf, pid_t pid)
+glibtop_get_proc_io(glibtop_proc_io *buf, pid_t pid)
{
- return glibtop_get_proc_diskio_l(glibtop_global_server, buf, pid);
+ return glibtop_get_proc_io_l(glibtop_global_server, buf, pid);
}
@@ -433,7 +433,7 @@ glibtop_get_proc_affinity(glibtop_proc_affinity *buf, pid_t pid)
}
/**
- * glibtop_get_proc_diskio: Get the disk io stats for the given pid
+ * glibtop_get_proc_io: Get the io stats for the given pid
* @buf: Buffer where the result will be given
* @pid: Process id to get the io stats for